@@ -102,6 +102,7 @@ class Normalizer(BaseNormalizer):
         '''
         
         self.valid_consonants_after_to_and_hosonto      =       ['ত','থ','ন','ব','ম','য','র'] 
+        self.decomp_level_ops["base_bangla_compose"]    =       self.baseCompose
         self.decomp_level_ops["ToAndHosontoNormalize"]  =       self.normalizeToandHosonto
 
         # invalid folas 
@@ -130,18 +131,67 @@ class Normalizer(BaseNormalizer):
                         self.decomp[idx+1]=None
                     elif d=='ঃ' and self.decomp[idx+1]== 'ং':
                         self.decomp[idx+1]=None
-                    
+    
+    def fixNoSpaceChar(self):
+        # replace
+        for idx,d in enumerate(self.decomp):
+            if idx==0 and self.decomp[idx] in ["\u200c","\u200d"]:
+                self.decomp[idx]=None
+            else:
+                if self.decomp[idx]=="\u200c":
+                    self.decomp[idx]="\u200d"   
+        self.decomp=[x for x in self.decomp if x is not None] 
+        # strict
+        for idx,d in enumerate(self.decomp):
+            if idx>0:
+                if self.decomp[idx]=="\u200d":
+                    # last one
+                    if idx==len(self.decomp)-1:
+                        self.decomp[idx]=None
+                    else: 
+                        # if previous one is a connector
+                        if self.decomp[idx-1]==self.lang.connector:
+                            self.decomp[idx]=None
+                            self.decomp[idx-1]=None
+                        # if previous one is not 'র'
+                        elif self.decomp[idx-1]!='র':
+                            self.decomp[idx]=None
+                        else:
+                            # if prev='র' and the prev-1 is not a connector
+                            if idx>1 and self.decomp[idx-2]==self.lang.connector:
+                                self.decomp[idx]=None
+                            # if the next is not a connector
+                            elif idx<len(self.decomp)-1 and self.decomp[idx+1]!=self.lang.connector:
+                                self.decomp[idx]=None
+                            # if the next one to connector is not "য"
+                            elif idx<len(self.decomp)-2 and self.decomp[idx+2]!="য" and self.decomp[idx+1]!=self.lang.connector:
+                                self.decomp[idx]=None
+                            else:
+                                # the actual allowed case
+                                self.decomp[idx-1]+=self.decomp[idx]
+                                self.decomp[idx]=None
+        self.decomp=[x for x in self.decomp if x is not None] 
+        
+                
              
 ##------------------------------------------------------------------------------------------------------    
     def cleanInvalidConnector(self):
         for idx,d in enumerate(self.decomp):
             if idx<len(self.decomp)-1:
-                if d==self.lang.connector and self.decomp[idx+1]!="য" and self.decomp[idx-1]!='অ': # exception
+                if d==self.lang.connector and self.decomp[idx+1]!="য" and self.decomp[idx-1] not in ['অ','এ']: # exception
                     if self.decomp[idx-1] in self.lang.invalid_connectors  or self.decomp[idx+1] in self.lang.invalid_connectors:
                         self.decomp[idx]=None 
+                if d==self.lang.connector and self.decomp[idx-1]=="য" and self.decomp[idx+1]!="য":
+                    self.decomp[idx]=None
+                if d==self.lang.connector and self.decomp[idx-1]=="ব" and self.decomp[idx+1] not in ['জ', 'দ', 'ধ', 'ব', 'য', 'র', 'ল']:
+                    self.decomp[idx]=None
+
         # handle exception
         self.decomp=[d for d in self.decomp if d is not None]
         word="".join(self.decomp)
+        
+        if "এ্যা" in word:
+            word=word.replace("এ্যা","অ্যা")
         if 'অ্য' in word:
             word=word.replace('অ্য',"অ্যা")
         self.decomp=[ch for ch in word]
@@ -261,38 +311,44 @@ class Normalizer(BaseNormalizer):
                     self.decomp[idx]=None
                     self.decomp[idx+1]=None
         
-    def fixRefOrder(self):
-        for idx,d in enumerate(self.decomp):
-            if idx<len(self.decomp)-3:
-                if  d=='র' and self.decomp[idx-1]==self.lang.connector\
-                    and self.decomp[idx+2]=='র' and self.decomp[idx+3]== self.lang.connector:
-                    self.decomp[idx]=None
-                    self.decomp[idx+1]=None
+    # def fixRefOrder(self):
+    #     for idx,d in enumerate(self.decomp):
+    #         if idx<len(self.decomp)-3:
+    #             if  d=='র' and self.decomp[idx-1]==self.lang.connector\
+    #                 and self.decomp[idx+2]=='র' and self.decomp[idx+3]== self.lang.connector:
+    #                 self.decomp[idx]=None
+    #                 self.decomp[idx+1]=None
         
-    def fixOrdersForCC(self):
-        self.constructComplexDecomp()
-        for idx,d in enumerate(self.decomp):
-            if self.lang.connector in d:
-                if d[0]=='র' and d[1]==self.lang.connector:
-                    start=['র',self.lang.connector]
-                    d=d[2:]
-                else:
-                    start=[]
+    # def fixOrdersForCC(self):
+    #     self.constructComplexDecomp()
+    #     print(self.decomp)
+    #     for idx,d in enumerate(self.decomp):
+    #         if self.lang.connector in d:
+    #             if d[0]=='র' and d[1]==self.lang.connector:
+    #                 start=['র',self.lang.connector]
+    #                 d=d[2:]
+    #             else:
+    #                 start=[]
+    #             print(start)
+    #             curr=[c for c in d if c!=self.lang.connector] 
+    #             # recreate order
+    #             order= ['ব','র','য']
+    #             order=[k for k in order if k in curr]
+    #             print(order)
+    #             order=[c for c in curr if c not in order]+order
+    #             print(order)
                 
-                curr=[c for c in d if c!=self.lang.connector] 
-                # recreate order
-                order= ['ব','র','য']
-                order=[k for k in order if k in curr]
-                order=[c for c in curr if c not in order]+order
-                # sort
-                curr=sorted(curr,key=order.index)
-
-                new=[]
-                for i in range(len(curr)):
-                    new.append(curr[i])
-                    new.append(self.lang.connector)
-                new=new[:-1]
-                self.decomp[idx]="".join(start+new)
+    #             # sort
+    #             curr=sorted(curr,key=order.index)
+    #             print(curr)
+                
+    #             new=[]
+    #             for i in range(len(curr)):
+    #                 new.append(curr[i])
+    #                 new.append(self.lang.connector)
+    #             new=new[:-1]
+    #             print(new)
+    #             self.decomp[idx]="".join(start+new)
         
 
     def cleanConnectotForJoFola(self):
@@ -314,8 +370,10 @@ class Normalizer(BaseNormalizer):
         self.safeop(self.fixTypoForJoFola)
         self.safeop(self.cleanDoubleCC)
         self.safeop(self.cleanDoubleRef)
-        self.safeop(self.fixRefOrder)
-        self.safeop(self.fixOrdersForCC)
+        # self.safeop(self.fixRefOrder)
+        # print("".join(self.decomp))
+        # #self.safeop(self.fixOrdersForCC)
+        #print("".join(self.decomp))
         self.safeop(self.cleanConnectotForJoFola)
         self.baseCompose()
 ##------------------------------------------------------------------------------------------------------               
@@ -332,6 +390,7 @@ class Normalizer(BaseNormalizer):
                 
                     d=root[j]
                     k=r+'্'+d
+                    #if k==
                     if k not in self.complex_roots:
                         formed.append(r)
                         break
